use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.006008
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
XKCD
cryptographically
freevocabulary
fs
ga
passphrase
rrrr
wordfrequency
wordlist
wordlists
David
Golden
dagolden
Mario
Domgoergen
mdom
Neil
Bowers
neil
lib
Crypt
Diceware
Wordlist
Original
Beale
Common
